@@ -4,9 +4,10 @@
 import flask
 # noinspection PyPackageRequirements
 import werkzeug.exceptions
+from joker.redis.error import ErrorInterface
+from volkanic import errors
 
-from joker.flasky import errors, viewutils
-from joker.flasky.loggers import ErrorInterface
+from joker.flasky import viewutils
 from joker.flasky.viewutils import decorate_all_view_funcs
 
 
