@@ -17,8 +17,10 @@ class JokerInterface(volkanic.GlobalInterface):
     def jinja2_env(self):
         # noinspection PyPackageRequirements
         from jinja2 import Environment, PackageLoader, select_autoescape
-        return Environment(
+        env = Environment(
             loader=PackageLoader(self.package_name, 'templates'),
             autoescape=select_autoescape(['html', 'xml']),
             **self.conf.get('_jinja2_env', {})
         )
+        env.policies["json.dumps_kwargs"]['ensure_ascii'] = False
+        return env
