@@ -3,20 +3,21 @@
 
 from __future__ import annotations
 
-import textwrap
 import dataclasses
 import datetime
 import decimal
 import functools
+
 import mimetypes
 import re
+import textwrap
+from collections import defaultdict
 from functools import cached_property
-from typing import Callable
-from typing import Union
+from typing import Union, Callable, Tuple, Iterable
 
 import flask
 import flask.views
-from flask import Flask
+from flask import Flask, Request
 from volkanic.utils import merge_dicts
 # noinspection PyPackageRequirements
 from werkzeug.routing import Rule
@@ -241,10 +242,21 @@ def url_for_this(**values):
     return flask.url_for(flask.request.endpoint, **values)
 
 
+def find_matching_rule(request: Request = None, app: Flask = None):
+    if request is None:
+        request = flask.request
+    if app is None:
+        app = flask.current_app
+    for rule in app.url_map.iter_rules():
+        rv = rule.match('|' + request.path)
+        if rv is None:
+            continue
+        return rule
+
+
 @dataclasses.dataclass
-class ViewEntry:
+class _RuleWrapper:
     rule: Rule
-    func: Callable
 
     @cached_property
     def methods(self) -> list[str]:
@@ -257,21 +269,59 @@ class ViewEntry:
         implicit = {'HEAD', 'OPTIONS'}
         return [s for s in self.methods if s not in implicit]
 
-    def fmt_methods(self, sep='|', implicit=False):
+    def fmt_methods(self, sep='|', implicit=False) -> str:
         methods = self.methods if implicit else self.explicit_methods
         return sep.join(methods)
 
+    def iter_captions(self) -> Iterable[Tuple[str, str]]:
+        for method in self.explicit_methods:
+            yield method, self.rule.rule
+
+
+class ViewEntry:
+    def __init__(self, func: Callable, *rules: Rule):
+        if not rules:
+            c = self.__class__.__name__
+            raise ValueError(f'{c} requires at least 1 rule in arguments')
+        self.func = func
+        self._rules = rules
+        self._rulewrappers = [_RuleWrapper(r) for r in rules]
+
+    @property
+    def endpoint(self) -> str:
+        return self._rules[0].endpoint
+
+    @property
+    def funcname(self) -> str:
+        return self.endpoint.split('.')[-1]
+
     @property
     def help(self) -> dict:
         return getattr(self.func, 'help', {})
 
-    @property
+    def iter_captions(self) -> Iterable[Tuple[str, str]]:
+        for rw in self._rulewrappers:
+            yield from rw.iter_captions()
+
+    @cached_property
     def docstring(self) -> str:
-        return textwrap.dedent(self.func.__doc__ or '')
+        s = textwrap.dedent(self.func.__doc__ or '')
+        return re.sub(r'^\s+|\s+$', '', s)
+
+    @cached_property
+    def docstring_lines(self) -> list[str]:
+        return self.docstring.splitlines()
+
+    @cached_property
+    def docstring_title(self) -> str:
+        if not self.docstring_lines:
+            return ''
+        return self.docstring_lines[0]
 
     @classmethod
     def get_all(cls, app: Flask) -> dict[str, ViewEntry]:
-        # entries = {}
-        rules = {r.endpoint: r for r in app.url_map.iter_rules()}
         funcs = app.view_functions
-        return {k: cls(rules[k], funcs[k]) for k in rules}
+        rules = defaultdict(list)
+        for rule in app.url_map.iter_rules():
+            rules[rule.endpoint].append(rule)
+        return {k: cls(funcs[k], *v) for k, v in rules.items()}
